@@ -1,10 +1,10 @@
 use crate::state::State;
 use crate::{Initiator, Responder, XXVault};
-use ockam_core::Result;
+use ockam_core::{async_trait, compat::boxed::Box};
+use ockam_core::{AsyncTryClone, Result};
 use ockam_key_exchange_core::NewKeyExchanger;
 
 /// Represents an XX NewKeyExchanger
-#[derive(Clone)]
 pub struct XXNewKeyExchanger<V: XXVault> {
     vault: V,
 }
@@ -16,18 +16,28 @@ impl<V: XXVault> XXNewKeyExchanger<V> {
     }
 }
 
+#[async_trait]
+impl<V: XXVault> AsyncTryClone for XXNewKeyExchanger<V> {
+    async fn async_try_clone(&self) -> Result<Self> {
+        Ok(Self {
+            vault: self.vault.async_try_clone().await?,
+        })
+    }
+}
+
+#[async_trait]
 impl<V: XXVault> NewKeyExchanger for XXNewKeyExchanger<V> {
     type Initiator = Initiator<V>;
     type Responder = Responder<V>;
     /// Create a new initiator using the provided backing vault
-    fn initiator(&self) -> Result<Initiator<V>> {
-        let ss = State::new(&self.vault)?;
+    async fn initiator(&self) -> Result<Initiator<V>> {
+        let ss = State::new(&self.vault).await?;
         Ok(Initiator::new(ss))
     }
 
     /// Create a new responder using the provided backing vault
-    fn responder(&self) -> Result<Responder<V>> {
-        let ss = State::new(&self.vault)?;
+    async fn responder(&self) -> Result<Responder<V>> {
+        let ss = State::new(&self.vault).await?;
         Ok(Responder::new(ss))
     }
 }
